===============================
metawrap
===============================


.. image:: https://img.shields.io/pypi/v/metawrap.svg
        :target: https://pypi.python.org/pypi/metawrap

.. image:: https://img.shields.io/travis/jakirkham/metawrap.svg
        :target: https://travis-ci.org/jakirkham/metawrap

.. image:: https://readthedocs.org/projects/metawrap/badge/?version=latest
        :target: https://metawrap.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://coveralls.io/repos/github/jakirkham/metawrap/badge.svg
        :target: https://coveralls.io/github/jakirkham/metawrap
        :alt: Coveralls

.. image:: https://img.shields.io/github/license/jakirkham/metawrap.svg
        :target: ./LICENSE.txt
        :alt: License


A collection of wrappers for functions and classes.


* Free software: BSD 3-Clause
* Documentation: https://metawrap.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `nanshe-org/nanshe-cookiecutter`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`nanshe-org/nanshe-cookiecutter`: https://github.com/nanshe-org/nanshe-cookiecutter

